@@ -66,13 +66,12 @@ struct _AdwStyleManager
   AdwSettings *settings;
   GtkSettings *gtk_settings;
   GtkCssProvider *provider;
-  GtkCssProvider *colors_provider;
   GtkCssProvider *accent_provider;
   GtkCssProvider *fonts_provider;
 
   AdwColorScheme color_scheme;
   gboolean dark;
-  gboolean setting_dark;
+  gboolean changing_gtk_settings;
   char *document_font_name;
   char *monospace_font_name;
 
@@ -103,17 +102,17 @@ static GHashTable *display_style_managers = NULL;
 static AdwStyleManager *default_instance = NULL;
 
 typedef enum {
-  UPDATE_BASE         = 1 << 0,
+  UPDATE_CONTRAST         = 1 << 0,
   UPDATE_COLOR_SCHEME = 1 << 1,
   UPDATE_ACCENT_COLOR = 1 << 2,
   UPDATE_FONTS        = 1 << 3,
-  UPDATE_ALL = UPDATE_BASE | UPDATE_COLOR_SCHEME | UPDATE_ACCENT_COLOR | UPDATE_FONTS
+  UPDATE_ALL = UPDATE_CONTRAST | UPDATE_COLOR_SCHEME | UPDATE_ACCENT_COLOR | UPDATE_FONTS
 } StylesheetUpdateFlags;
 
 static void
 warn_prefer_dark_theme (AdwStyleManager *self)
 {
-  if (self->setting_dark)
+  if (self->changing_gtk_settings)
     return;
 
   g_warning ("Using GtkSettings:gtk-application-prefer-dark-theme with "
@@ -250,34 +249,6 @@ update_stylesheet (AdwStyleManager       *self,
                                               GTK_STYLE_PROVIDER (self->animations_provider),
                                               10000);
 
-  if (flags & UPDATE_COLOR_SCHEME) {
-    self->setting_dark = TRUE;
-
-    g_object_set (self->gtk_settings,
-                  "gtk-application-prefer-dark-theme", self->dark,
-                  NULL);
-
-    self->setting_dark = FALSE;
-}
-
-  if (flags & UPDATE_BASE && self->provider) {
-    if (adw_settings_get_high_contrast (self->settings))
-      gtk_css_provider_load_from_resource (self->provider,
-                                           "/org/gnome/Adwaita/styles/base-hc.css");
-    else
-      gtk_css_provider_load_from_resource (self->provider,
-                                           "/org/gnome/Adwaita/styles/base.css");
-  }
-
-  if (flags & UPDATE_COLOR_SCHEME && self->colors_provider) {
-    if (self->dark)
-      gtk_css_provider_load_from_resource (self->colors_provider,
-                                           "/org/gnome/Adwaita/styles/defaults-dark.css");
-    else
-      gtk_css_provider_load_from_resource (self->colors_provider,
-                                           "/org/gnome/Adwaita/styles/defaults-light.css");
-  }
-
   if (flags & UPDATE_ACCENT_COLOR && self->accent_provider) {
     char *accent_css = generate_accent_css (self);
     gtk_css_provider_load_from_string (self->accent_provider, accent_css);
@@ -290,6 +261,50 @@ update_stylesheet (AdwStyleManager       *self,
     g_free (fonts_css);
   }
 
+  if (flags & UPDATE_COLOR_SCHEME) {
+    GtkInterfaceColorScheme color_scheme;
+
+    if (self->dark)
+      color_scheme = GTK_INTERFACE_COLOR_SCHEME_DARK;
+    else
+      color_scheme = GTK_INTERFACE_COLOR_SCHEME_LIGHT;
+
+    if (self->provider)
+      g_object_set (self->provider, "prefers-color-scheme", color_scheme, NULL);
+
+    self->changing_gtk_settings = TRUE;
+
+    g_object_set (self->gtk_settings,
+                  "gtk-application-prefer-dark-theme", self->dark,
+                  NULL);
+
+    g_object_set (self->gtk_settings,
+                  "gtk-interface-color-scheme", color_scheme,
+                  NULL);
+
+    self->changing_gtk_settings = FALSE;
+  }
+
+  if (flags & UPDATE_CONTRAST) {
+    GtkInterfaceContrast contrast;
+
+    if (adw_settings_get_high_contrast (self->settings))
+      contrast = GTK_INTERFACE_CONTRAST_MORE;
+    else
+      contrast = GTK_INTERFACE_CONTRAST_NO_PREFERENCE;
+
+    if (self->provider)
+      g_object_set (self->provider, "prefers-contrast", contrast, NULL);
+
+    self->changing_gtk_settings = TRUE;
+
+    g_object_set (self->gtk_settings,
+                  "gtk-interface-contrast", contrast,
+                  NULL);
+
+    self->changing_gtk_settings = FALSE;
+  }
+
   self->animation_timeout_id =
     g_timeout_add_once (SWITCH_DURATION,
                         (GSourceOnceFunc) enable_animations_cb,
@@ -426,7 +441,7 @@ notify_system_supports_accent_colors_cb (AdwStyleManager *self)
 static void
 notify_high_contrast_cb (AdwStyleManager *self)
 {
-  update_stylesheet (self, UPDATE_BASE);
+  update_stylesheet (self, UPDATE_CONTRAST);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_HIGH_CONTRAST]);
 }
@@ -462,15 +477,12 @@ adw_style_manager_constructed (GObject *object)
                     NULL);
 
       self->provider = gtk_css_provider_new ();
+      gtk_css_provider_load_from_resource (self->provider,
+                                           "/org/gnome/Adwaita/styles/main.css");
       gtk_style_context_add_provider_for_display (self->display,
                                                   GTK_STYLE_PROVIDER (self->provider),
                                                   GTK_STYLE_PROVIDER_PRIORITY_THEME);
 
-      self->colors_provider = gtk_css_provider_new ();
-      gtk_style_context_add_provider_for_display (self->display,
-                                                  GTK_STYLE_PROVIDER (self->colors_provider),
-                                                  GTK_STYLE_PROVIDER_PRIORITY_THEME);
-
       self->accent_provider = gtk_css_provider_new ();
       gtk_style_context_add_provider_for_display (self->display,
                                                   GTK_STYLE_PROVIDER (self->accent_provider),
@@ -544,7 +556,6 @@ adw_style_manager_dispose (GObject *object)
 
   g_clear_handle_id (&self->animation_timeout_id, g_source_remove);
   g_clear_object (&self->provider);
-  g_clear_object (&self->colors_provider);
   g_clear_object (&self->animations_provider);
   g_clear_object (&self->accent_provider);
   g_clear_object (&self->fonts_provider);
@@ -791,9 +802,9 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    * The system document font.
    *
    * The font is in the same format as [property@Gtk.Settings:gtk-font-name],
-   * e.g. "Adwaita Sans 11".
+   * e.g. "Adwaita Sans 12".
    *
-   * Use [func@Pango.FontDescription.to_string] to parse it.
+   * Use [func@Pango.FontDescription.from_string] to parse it.
    *
    * Since: 1.7
    */
@@ -810,7 +821,7 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    * The font is in the same format as [property@Gtk.Settings:gtk-font-name],
    * e.g. "Adwaita Mono 11".
    *
-   * Use [func@Pango.FontDescription.to_string] to parse it.
+   * Use [func@Pango.FontDescription.from_string] to parse it.
    *
    * Since: 1.7
    */
@@ -1145,9 +1156,9 @@ adw_style_manager_get_accent_color_rgba (AdwStyleManager *self)
  * Gets the system document font.
  *
  * The font is in the same format as [property@Gtk.Settings:gtk-font-name],
- * e.g. "Adwaita Sans 11".
+ * e.g. "Adwaita Sans 12".
  *
- * Use [func@Pango.FontDescription.to_string] to parse it.
+ * Use [func@Pango.FontDescription.from_string] to parse it.
  *
  * Returns: the system document font
  *
@@ -1173,7 +1184,7 @@ adw_style_manager_get_document_font_name (AdwStyleManager *self)
  * The font is in the same format as [property@Gtk.Settings:gtk-font-name],
  * e.g. "Adwaita Mono 11".
  *
- * Use [func@Pango.FontDescription.to_string] to parse it.
+ * Use [func@Pango.FontDescription.from_string] to parse it.
  *
  * Returns: the system monospace font
  *
